Learn R Programming

rpubmed (version 0.1)

record_counts_by_year: Gives a breakdown of records per year in a corpus of Pubmed Records

Description

Gives a breakdown of records per year in a corpus of Pubmed Records

Usage

record_counts_by_year(corpus, year_min = FALSE, year_max = FALSE)

Arguments

corpus
a list of Pubmed records e.g. as given by fetch_in_chunks()
year_min
integer representing the earliest year to be included in the counts
year_max
integer representing the latest year to be included in the counts. Frequencies are calculated after the dataset is truncated.

Value

dataframe with year, records and freq columns