Rdocumentation
powered by
Learn R Programming
rpubmed (version 0.1)
term_in_text_p: predicate function for presence of a term in an article text
Description
predicate function for presence of a term in an article text
Usage
term_in_text_p(term, text, case_sensitive, ...)
Arguments
term
string
text
article text
case_sensitive
logical
...
arguments to be passed to grep